Index: trunk/psModules/src/objects/pmPSFtry.h
===================================================================
--- trunk/psModules/src/objects/pmPSFtry.h	(revision 5844)
+++ trunk/psModules/src/objects/pmPSFtry.h	(revision 6872)
@@ -6,6 +6,6 @@
  *  @author EAM, IfA
  *
- *  @version $Revision: 1.3 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2005-12-24 01:24:32 $
+ *  @version $Revision: 1.4 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2006-04-17 18:01:05 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -18,11 +18,11 @@
 
 /**
- *
+ * 
  * This structure contains a pointer to the collection of sources which will
  * be used to test the PSF model form. It lists the pmModelType type of model
  * being tests, and contains an element to store the resulting psf
  * representation. In addition, this structure carries the complete collection of
  * FLT (floating parameter) and PSF (fixed parameter) model fits to each of the
  * sources modelFLT and modelPSF. It also contains a mask which is set by the
  * model fitting and psf fitting steps. For each model, the value of the quality
  * metric is stored in the vector metric and the fitted instrumental magnitude is
@@ -38,9 +38,9 @@
  * ultimate metric to intercompare multiple types of PSF models is the value of
  * the aperture correction scatter.
- *
+ * 
  * XXX: There are many more members in the SDRS then in the prototype code.
  * I stuck with the prototype code.
- *
- *
+ * 
+ * 
  */
 typedef struct
@@ -48,5 +48,5 @@
     pmPSF      *psf;                    ///< Add comment.
     psArray    *sources;                ///< pointers to the original sources
-    psArray    *modelFLT;               ///< model fits, floating parameters
+    psArray    *modelEXT;               ///< model fits, floating parameters
     psArray    *modelPSF;               ///< model fits, PSF parameters
     psVector   *mask;                   ///< Add comment.
@@ -58,13 +58,13 @@
 
 /** pmPSFtryMaskValues
- *
+ * 
  * The following datatype defines the masks used by the pmPSFtry analysis to
  * identify sources which should or should not be included in the analysis.
- *
+ * 
  */
-enum {
+typedef enum {
     PSFTRY_MASK_CLEAR    = 0x00,        ///< Add comment.
     PSFTRY_MASK_OUTLIER  = 0x01,        ///< 1: outlier in psf polynomial fit (provided by psPolynomials)
-    PSFTRY_MASK_FLT_FAIL = 0x02,        ///< 2: flt model failed to converge
+    PSFTRY_MASK_EXT_FAIL = 0x02,        ///< 2: ext model failed to converge
     PSFTRY_MASK_PSF_FAIL = 0x04,        ///< 3: psf model failed to converge
     PSFTRY_MASK_BAD_PHOT = 0x08,        ///< 4: invalid source photometry
@@ -74,33 +74,35 @@
 
 /** pmPSFtryAlloc()
- *
+ * 
  * Allocate a pmPSFtry data structure.
- *
+ * 
  */
 pmPSFtry *pmPSFtryAlloc(
     psArray *stars,                     ///< Add comment.
-    char *modelName                     ///< Add comment.
+    char *modelName,                     ///< Add comment.
+    bool poissonErrors   // use poissonian or constant errors?
 );
 
 
 /** pmPSFtryModel()
- *
+ * 
  * This function takes the input collection of sources and performs a complete
  * analysis to determine a PSF model of the given type (specified by model name).
  * The result is a pmPSFtry with the results of the analysis.
- *
+ * 
  */
 pmPSFtry *pmPSFtryModel(
     psArray *sources,                   ///< Add comment.
     char *modelName,                    ///< Add comment.
-    float radius                        ///< Add comment.
+    float radius,                     ///< Add comment.
+    bool poissonErrors   // use poissonian or constant errors?
 );
 
 
 /** pmPSFtryMetric()
- *
+ * 
  * This function is used to measure the PSF model metric for the set of
  * results contained in the pmPSFtry structure.
- *
+ * 
  */
 bool pmPSFtryMetric(
@@ -18,11 +18,11 @@
  * being tests, and contains an element to store the resulting psf
  * representation. In addition, this structure carries the complete collection of
- * FLT (floating parameter) and PSF (fixed parameter) model fits to each of the
- * sources modelFLT and modelPSF. It also contains a mask which is set by the
+ * EXT (floating parameter) and PSF (fixed parameter) model fits to each of the
+ * sources modelEXT and modelPSF. It also contains a mask which is set by the
  * model fitting and psf fitting steps. For each model, the value of the quality
  * metric is stored in the vector metric and the fitted instrumental magnitude is
